GettextLocalizationsDelegate class

LocalizationsDelegate for GettextLocalizations

Inheritance

Constructors

GettextLocalizationsDelegate({String defaultLanguage = 'en', OnWarning? onWarning = print})

Properties

defaultLanguage → String
final
hashCode → int
The hash code for this object.
no setterinherited
onWarning → OnWarning?
Sink for missing-translation warnings, forwarded to GettextLocalizations. Defaults to print. Pass null to silence the warnings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the object returned by the load method, T by default.
no setterinherited

Methods

isSupported(Locale locale) → bool
Whether resources for the given locale can be loaded by this delegate.
override
load(Locale locale) → Future<GettextLocalizations>
Start loading the resources for locale. The returned future completes when the resources have finished loading.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldReload(covariant GettextLocalizationsDelegate old) → bool
Returns true if the resources for this delegate should be loaded again by calling the load method.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited