Translations class

Represents translation domain

Constructors

Translations(Map<String, Map<String, Translation>> contexts)
const
Translations.fromJson(Map<String, dynamic> contexts)
Factory to get translations from generic json structure
factory

Properties

contexts → Map<String, Map<String, Translation>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTranslation(String msgctxt, String msgid) → Translation?
Get translation by message id and context
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited