Table class

Constructors

Table(Map<String, dynamic> table)
Table.fromCharset({String charset = 'utf-8'})

Properties

charset ↔ String
getter/setter pair
contentType ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toMap → Map<String, dynamic>
no setter
translations ↔ Map<String, Map<String, dynamic>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited