PoCompiler class

Compiles a PO file from a Table object

Constructors

PoCompiler(Map<String, dynamic> source, {int foldLength = 76})

Properties

foldLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table
final

Methods

compile() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited